/***********************************************************************/
/*                                                                     */
/*  FILE        :Main.c or Main.cpp                                    */
/*  DATE        :Mon, Mar 27, 2017                                     */
/*  DESCRIPTION :Main Program                                          */
/*  CPU TYPE    :                                                      */
/*                                                                     */
/*  NOTE:THIS IS A TYPICAL EXAMPLE.                                    */
/*                                                                     */
/***********************************************************************/

/*******************************************************************************
Includes <System Includes> , "Project Includes"
*******************************************************************************/
//#include "typedefine.h"
#include "iodefine.h"
#include "stdbool.h"
#include "R_PG_SCI_RX63N.h"
#include <string.h>

/*******************************************************************************
Macro definitions
*******************************************************************************/
#define BUFF_SIZE       (13)                        /* setting buffer size */

/*******************************************************************************
Exported global variables and functions (to be accessed by other files)
*******************************************************************************/
void main(void);

/*******************************************************************************
* Constant Definition
*******************************************************************************/
const uint8_t send_buf[BUFF_SIZE] = "Hello World!"; /* send data from SCI0 to SCI2 */

/*******************************************************************************
* Private global variables and functions
*******************************************************************************/
uint8_t CH0_read_buf[BUFF_SIZE];                    /* read buffer for SCI0 */
uint8_t CH2_read_buf[BUFF_SIZE];                    /* read buffer for SCI2 */


/*******************************************************************************
* Function Name: main
* Description  : Main program
* Arguments    : none
* Return Value : none
*******************************************************************************/
void main(void)
{
    R_PG_SCI_StartReceiving_C2(CH2_read_buf, BUFF_SIZE);        /* Receive from SCI0 */
    R_PG_SCI_StartSending_C0((uint8_t *)send_buf, BUFF_SIZE);   /* Send data to SCI2 */

    while(1);
}

/*******************************************************************************
* Function Name: Sci0TrFunc
* Description  : Finish sending(SCI0)
* Arguments    : none
* Return Value : none
*******************************************************************************/
void Sci0TrFunc(void)
{
    R_PG_SCI_StartReceiving_C0(CH0_read_buf, BUFF_SIZE);    /* Receive data */
}

/*******************************************************************************
* Function Name: Sci0ReFunc
* Description  : Finish receiving(SCI0)
* Arguments    : none
* Return Value : none
*******************************************************************************/
void Sci0ReFunc(void)
{
    /* send/receive OK ? */
    if ( 0 == strcmp((const char *)CH0_read_buf, (const char *)send_buf) )
    {
        R_PG_IO_PORT_Write_PD6(0);    /* Turn on LED1 */
    }
    else
    {
        /* Do nothing */
    }
}

/*******************************************************************************
* Function Name: Sci2ReFunc
* Description  : Finish receiving(SCI2)
* Arguments    : none
* Return Value : none
*******************************************************************************/
void Sci2ReFunc(void)
{
    R_PG_SCI_StartSending_C2(CH2_read_buf, BUFF_SIZE);  /* Send back to SCI0 */
}

/*******************************************************************************
* Function Name: Sci2TrFunc
* Description  : Finish sending(SCI2)
* Arguments    : none
* Return Value : none
*******************************************************************************/
void Sci2TrFunc(void)
{
    /* Do nothing */
}

/******************************************************************************
Option-Setting Memory
******************************************************************************/
#pragma address OFS1_REG = 0xFFFFFF88   /* OFS1 register */
const unsigned long OFS1_REG = 0xFFFFFFFF;

#pragma address OFS0_REG = 0xFFFFFF8C   /* OFS0 register */
const unsigned long OFS0_REG = 0xFFFFFFFF;
